@@ -1,8 +1,10 @@
 package Getopt::Flex::Config;
-our $VERSION = '0.72';
+our $VERSION = '1.00';
 
 # ABSTRACT: Getopt::Flex's way of handling config
 
+use strict; #shut up cpants
+use warnings; #shut up cpants
 use Moose;
 use MooseX::StrictConstructor;
 use Moose::Util::TypeConstraints;
@@ -103,7 +105,7 @@ Getopt::Flex::Config - Getopt::Flex's way of handling config
 
 =head1 VERSION
 
-version 0.72
+version 1.00
 
 =head1 DESCRIPTION
 
